@@ -19,7 +19,6 @@
 /* Headers we may want to use. */
 #define STDC_HEADERS 1
 /* #undef _GNU_SOURCE */
-#define HAVE_ALIGNED_ALLOC 1
 /* #undef HAVE_ALLOCA_H */
 #define HAVE_ARPA_INET_H 1
 /* #undef HAVE_ASM_TERMBITS_H */
@@ -35,6 +34,11 @@
 #define HAVE_FLOAT_H 1
 #define HAVE_FNMATCH_H 1
 /* #undef HAVE_FPU_CONTROL_H */
+/* #undef HAVE_GETMNTENT */
+/* #undef HAVE_GETMNTENT_IN_SYS_MNTAB */
+#define HAVE_GETMNTINFO 1
+/* #undef HAVE_GETMNTINFO64 */
+/* #undef HAVE_GETMNTINFO_TAKES_statvfs */
 #define HAVE_GRP_H 1
 /* #undef HAVE_IA64INTRIN_H */
 #define HAVE_IEEEFP_H 1
@@ -209,6 +213,7 @@
 #define HAVE_SELECT 1
 #define HAVE_SETENV 1
 #define HAVE_SETLOCALE 1
+/* #undef HAVE_SETMNTENT */
 #define HAVE_SETUPTERM 1
 /* #undef HAVE_SIGSET */
 #define HAVE_SIGACTION 1
@@ -276,10 +281,10 @@
   #define SIZEOF_SIZE_T  SIZEOF_LONG
 #else
 /* No indentation, to fetch the lines from verification scripts */
-#define SIZEOF_LONG   4
-#define SIZEOF_VOIDP  4
-#define SIZEOF_CHARP  4
-#define SIZEOF_SIZE_T 4
+#define SIZEOF_LONG   8
+#define SIZEOF_VOIDP  8
+#define SIZEOF_CHARP  8
+#define SIZEOF_SIZE_T 8
 #endif
 
 #define HAVE_LONG 1
@@ -294,7 +299,7 @@
 /* #undef HAVE_UCHAR */
 #define SIZEOF_UINT 4
 #define HAVE_UINT 1
-#define SIZEOF_ULONG 4
+#define SIZEOF_ULONG 8
 #define HAVE_ULONG 1
 /* #undef SIZEOF_INT8 */
 /* #undef HAVE_INT8 */
@@ -393,8 +398,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "OpenBSD"
-#define MACHINE_TYPE "i386"
-#define DEFAULT_MACHINE "i386"
+#define MACHINE_TYPE "amd64"
+#define DEFAULT_MACHINE "amd64"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -529,16 +534,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 6
-#define MYSQL_VERSION_PATCH 9
+#define MYSQL_VERSION_PATCH 10
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.6.9"
+#define PACKAGE_STRING "MySQL Server 10.6.10"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.6.9"
-#define VERSION "10.6.9"
+#define PACKAGE_VERSION "10.6.10"
+#define VERSION "10.6.10"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
